####################
Django Google Mailer
####################

.. image:: https://travis-ci.com/nikhiljohn10/django-google-mailer.svg?branch=main
    :target: https://travis-ci.com/nikhiljohn10/django-google-mailer
.. image:: https://readthedocs.org/projects/django-google-mailer/badge/?version=stable
  :target: https://django-google-mailer.readthedocs.io/en/stable/?badge=stable
  :alt: Documentation Status
.. image:: https://img.shields.io/github/v/release/nikhiljohn10/django-google-mailer
  :alt: GitHub release
.. image:: https://img.shields.io/pypi/status/django-google-mailer
  :alt: PyPI - Status
.. image:: https://img.shields.io/pypi/v/django-google-mailer
  :target: https://pypi.org/project/django-google-mailer
  :alt: PyPI
.. image:: https://img.shields.io/pypi/pyversions/django-google-mailer
  :alt: PyPI - Python Version
.. image:: https://img.shields.io/pypi/djversions/django-google-mailer
  :alt: PyPI - Django Version
.. image:: https://img.shields.io/pypi/dm/django-google-mailer
  :alt: PyPI - Downloads
.. image:: https://img.shields.io/pypi/l/django-google-mailer
  :alt: PyPI - License

Django Google Mailer is a Django package which uses Gmail API to send emails to users as an administrator.

Documentation version: |release|

Contents
^^^^^^^^

.. toctree::
  :maxdepth: 3
  :hidden:

  Home <self>

.. toctree::

  quick-start
  Reference <modules>

.. toctree::
  :hidden:

  Versions <change>
  Package <https://pypi.org/project/django-google-mailer/>
  Source <https://github.com/nikhiljohn10/django-google-mailer>
  genindex

License
=======

.. include:: ../LICENSE

.. meta::
  :description: Django Google Mailer is a Django app which is an alternative to send emails using Google's Gmail API. This is the most secure method as it uses OAuth 2.0.
  :keywords: django, google, gmail, api, python package

Google Privacy Policies
=======================

- `Google APIs Terms of Service <https://developers.google.com/terms>`_
- `Google API Services User Data Policy <https://developers.google.com/terms/api-services-user-data-policy>`_

References
==========

1. `Google Auth OAuth Library <https://github.com/googleapis/google-auth-library-python-oauthlib>`_
2. `Google Auth OAuth Library Docs <https://google-auth-oauthlib.readthedocs.io/en/latest/>`_
3. `Google API Client <https://github.com/googleapis/google-api-python-client>`_
4. `Google API Client Docs <https://googleapis.github.io/google-api-python-client/docs/>`_
